#include "network.h"
#include <enet.h>


class ENetServer : public Network {
public:
    ENetServer() : server(nullptr) {}

    void Initialize() override {
        if (enet_initialize() != 0) {
            std::cerr << "An error occurred while initializing ENet.\n";
            exit(EXIT_FAILURE);
        }

        ENetAddress address;
        address.host = ENET_HOST_ANY;
        address.port = 1234;

        server = enet_host_create(&address, 32, 2, 0, 0);
        if (!server) {
            std::cerr << "An error occurred while trying to create the server.\n";
            exit(EXIT_FAILURE);
        }
    }

    void Shutdown() override {
        enet_host_destroy(server);
        enet_deinitialize();
    }

    void SendData(const void* data, size_t size) override {
        ENetPacket* packet = enet_packet_create(data, size, ENET_PACKET_FLAG_RELIABLE);
        enet_host_broadcast(server, 0, packet);
    }

    void ReceiveData() override {
        ENetEvent event;
        while (enet_host_service(server, &event, 0) > 0) {
            if (event.type == ENET_EVENT_TYPE_RECEIVE) {
                std::cout << "Received packet from client: " << event.packet->data << "\n";
                enet_packet_destroy(event.packet);
            }
        }
    }

private:
    ENetHost* server;
};
